@@ -33,6 +33,7 @@ class SkillCreator:
 
 		self.generalQuestions()
 		self.createDestinationFolder()
+		self.createBaseFiles()
 		self.createInstructions()
 		self.createDialogTemplates()
 		self.createTalks()
@@ -218,6 +219,24 @@ class SkillCreator:
 		print('----------------------------\n')
 
 
+	def createBaseFiles(self):
+		print('Creating base files')
+		self.createTemplateFile(
+			outputPath=self._skillPath / '.gitignore',
+			templateFile='.gitignore.j2'
+		)
+
+		self.createTemplateFile(
+			outputPath=self._skillPath / 'LICENSE',
+			templateFile='LICENSE.j2'
+		)
+
+		self.createTemplateFile(
+			outputPath=self._skillPath / '.gitlab-ci.yml',
+			templateFile='.gitlab-ci.yml.j2'
+		)
+
+
 	def createInstructions(self):
 		if not self._general['createInstructions']:
 			return
@@ -464,8 +483,8 @@ def uploadSkillToGithub(githubToken: str, skillAuthor: str, skillName: str, skil
 
 		subprocess.run(f'git -C {str(skillPath)} init'.split())
 
-		subprocess.run(['git', 'config', '--global', 'user.email', 'githubbot@projectalice.io'])
-		subprocess.run(['git', 'config', '--global', 'user.name', 'githubbot@projectalice.io'])
+		subprocess.run(['git', '-C', str(skillPath), 'config', 'user.email', 'githubbot@projectalice.io'])
+		subprocess.run(['git', '-C', str(skillPath), 'config', 'user.name', 'ProjectAliceBot'])
 
 		remote = f'https://{skillAuthor}:{githubToken}@github.com/{skillAuthor}/skill_{skillName}.git'
 		subprocess.run(['git', '-C', str(skillPath), 'remote', 'add', 'origin', remote])
